import * as employee from "../../../support/testFunctions/employee/employees"
import * as template from "../../../support/testFunctions/templates"
import * as set from "../../../support/testFunctions/set_up"
import * as data from "../../../fixtures/data"
import { dashboardCareerTasks } from "./dashboard_career_tasks"
import { dashboardTeamTasks } from "./dashboard_team_tasks"

describe('Dashboard', () => {
    
    beforeEach(() => {

        cy.visit('/employees')
        cy.get('#mainContent > div.login-spinner').should('not.exist')
    })


    describe('Sets up workspace', () => {
        
        set.setConfiguration()
        
        set.setCharts()

        set.addEmployees()
    })

    describe('Career', () => {

        beforeEach(() => {

            cy.visit('/employees')
            cy.get('#mainContent > div.login-spinner').should('not.exist')
        })

        it('Adds milestone', () => {

            employee.openEmployeeCard(data.person[0].surname)
            employee.openTab('Career')

            template.addModule('PREBOARDING', false)
        })

        it('Adds new tasks', () => {

            employee.openEmployeeCard(data.person[0].surname)
            employee.openTab('Career')
            template.openModule('PREBOARDING')
            
            template.addTask('new task1', 'new task desc', false)
            template.addTask('new task2','new task desc', false)
            template.addTask('new task3', 'new task desc', false)
        })


        it('Adds another new milestone with section and task', () => {

            employee.openEmployeeCard(data.person[0].surname)
            employee.openTab('Career')

            template.addModule('ONBOARDING', false)
            template.openModule('ONBOARDING')
            
            template.addPhase('new section')
            template.addTask('new task', 'new task desc', false)
        })

        it('Adds new internal tasks', () => {

            employee.openEmployeeCard(data.person[0].surname)
            employee.openTab('Career')
            template.openModule('PREBOARDING')
            
            template.addInternalTask('new task1', 'description for my internal task', 'my internal task name1', null, data.person[1].surname)
            template.addInternalTask('new task1', 'description for my internal task', 'my internal task name2', null, data.person[1].surname)
            template.addInternalTask('new task2', 'description for my internal task', 'my internal task name3', null, 'Feuermann')
        })
    
        it('Adds milestone', () => {

            employee.openEmployeeCard(data.person[1].surname)
            employee.openTab('Career')

            template.addModule('ONBOARDING', false)
        })

        it('Adds new tasks', () => {

            employee.openEmployeeCard(data.person[1].surname)
            employee.openTab('Career')
            template.openModule('ONBOARDING')
            
            template.addTask('newest task1', 'new task desc', false)
            template.addTask('newest task2','new task desc', false)
        })

        it('Adds new internal tasks', () => {

            employee.openEmployeeCard(data.person[1].surname)
            employee.openTab('Career')
            template.openModule('ONBOARDING')
            
            template.addInternalTask('newest task1', 'description for my internal task', 'my internal task newest name1', null, 'Feuermann')
            template.addInternalTask('newest task1', 'description for my internal task', 'my internal task newest name2', null, data.person[0].surname)
        })
    })

    describe('Dashboard', () => {
    
        dashboardCareerTasks()

        dashboardTeamTasks()
    })
    
    describe('Cleans up workspace after tests', () => {
        
        set.deleteEmployees()
        
        set.deleteConfiguration()
    })
})