import * as set from "../../../support/testFunctions/set_up"
import * as inventory from "../../../support/testFunctions/inventory"
import * as employee from "../../../support/testFunctions/employee/employees"
import * as data from "../../../fixtures/data"

describe('Inventory', () => {

    beforeEach(() => {
        
        cy.visit('/inventory')
        cy.get('#mainContent > div.login-spinner').should('not.exist')
    })
  
    describe('Sets up workspace', () => {
        
        set.setConfiguration()
        
        set.setCharts()
        
        set.addEmployees()
    })
    
    describe('Inventory', () => {
        
        it('Adds item', () => {

            inventory.addInventoryItem(data.item[0])
        })

        it('Changes item details', () => {

            inventory.openInventoryDetail(data.item[0].name)
            inventory.changeInventoryInfo(data.item[1])
        })

        it('Deletes item', () => {

            inventory.openInventoryDetail(data.item[1].name)
            inventory.delInventoryItem(data.item[1].name)
        })
    })

    describe('Employee - inventory', () => {
        
        it('Adds item', () => {

            inventory.addInventoryItem(data.item[0])
        })

        it('Assigns inventory item', () => {

            cy.visit('/employees')
            cy.get('#mainContent > div.login-spinner').should('not.exist')
            employee.openEmployeeCard(data.person[0].surname)
            employee.openTab('Inventory')
            inventory.assignItem(data.item[0].name)
        })

        it('Check assigned item', () => {

            inventory.checkAssignedItem(data.item[0].name, data.person[0].surname)
        })

        it('Delete assigned item', () => {

            cy.visit('/employees')
            cy.get('#mainContent > div.login-spinner').should('not.exist')
            employee.openEmployeeCard(data.person[0].surname)
            employee.openTab('Inventory')
            inventory.openInventoryDetail(data.item[0].name)
            inventory.unassignItem(data.item[0].name)
        })

        it('Check unassigned item', () => {

            inventory.checkUnassignedItem(data.item[0].name)
        })

        it('Deletes inventory item', () => {
            
            inventory.openInventoryDetail(data.item[0].name)
            inventory.delInventoryItem(data.item[0].name)
        })
    })

    describe('Cleans up workspace after tests', () => {
        
        set.deleteEmployees()
            
        set.deleteConfiguration()
    })
})