import * as employee from "../../../support/testFunctions/employee/employees"
import * as set from "../../../support/testFunctions/set_up"
import * as data from "../../../fixtures/data"
import * as onboarding from "../../../support/testFunctions/onboarding"
import * as template from "../../../support/testFunctions/templates"
import * as positions from "../../../support/testFunctions/employee/position"

describe('Onboarding', () => {
    
    beforeEach(() => {
        
        cy.visit('/')
        cy.get('#mainContent > div.login-spinner').should('not.exist')
    })

    describe('Sets up workspace', () => {
        
        set.setConfiguration()
        
        set.setCharts()
        
        set.createContents()
        
        set.createTemplate()
        
        set.addEmployeesWithTemplate()
    })

    describe('Onboarding using template', () => {

        it('Fill in missing date', () => {

            cy.visit('/employees')
            cy.get('#mainContent > div.login-spinner').should('not.exist')
            employee.openEmployeeCard(data.person[1].surname)
            employee.openTab('Career')
            employee.addDateToModule('PREBOARDING', '1.3.2023')
            employee.addDateToModule('ONBOARDING', '1.3.2023')
        })

        it('Changes positions status', () => {

            cy.visit('/employees')
            cy.get('#mainContent > div.login-spinner').should('not.exist')
            employee.openEmployeeCard(data.person[1].surname)
            positions.changePositionStatus()
        })

        it("Opens employees onboarding process", () => {
          
            onboarding.openModule('PREBOARDING')
            onboarding.openTask('0 form')

            onboarding.completeTask('0 form', 'video')
        })
    })

    describe('Onboarding using career', () => {
        
        it('Adds new milestone and section', () => {

            cy.visit('/employees')
            cy.get('#mainContent > div.login-spinner').should('not.exist')
            employee.openEmployeeCard(data.person[1].surname)
            employee.openTab('Career')

            template.addModule('PROMOTION', false)
            template.openModule('PROMOTION')

            template.addPhase('new section')
        })

        it('Adds new tasks', () => {

            cy.visit('/employees')
            cy.get('#mainContent > div.login-spinner').should('not.exist')
            employee.openEmployeeCard(data.person[1].surname)
            employee.openTab('Career')
            template.openModule('PROMOTION')

            template.addTask('task0', 'new task desc', false, data.content[0])
            template.addTask('task2', 'new task desc', false, data.content[2])
            template.addTask('task8', 'new task desc', false, data.content[8])
        })

        it("Opens employees onboarding process and changes status", () => {
          
            onboarding.openModule('PROMOTION')

            onboarding.openTask('task0')
            onboarding.changeTaskState('task0', 'Rejected')

            onboarding.openTask('task0')
            onboarding.completeTask('task0', 'form')

            onboarding.openTask('task2')
            onboarding.changeTaskState('task2', 'Inprogress')
        })
    })

    describe('Cleans up workspace after tests', () => {

        set.deleteTemplate()
        
        set.deleteEmployees()
        
        set.deleteContents()
        
        set.deleteConfiguration()
    })
})