import * as configuration from "../../../support/testFunctions/settings/configuration"
import { confInfo } from "../../../support/testFunctions/settings/configuration"

export function configuration() {
    
    beforeEach(() => {

        cy.visit('/settings/configurations')
        cy.get('#mainContent > div.login-spinner').should('not.exist')
    })

    describe('Global tags configurations', () => {

        const info = confInfo["global tags"]

        it('Adds global tags', () => {

            configuration.addItem(info, 'IT')
            configuration.addItem(info, 'HR')
            configuration.addItem(info, 'Marketing')
        })

        it('Deletes global tags', () => {

            configuration.deleteItem(info, 'Marketing')
            configuration.deleteAllItems(info)
        })
    })

    describe('Languages', () => {

        const info = confInfo["languages"]

        it('Adds languages', () => {

            //select
            configuration.selectLanguage('en')

            //type
            configuration.addItem(info, 'cs')
            configuration.addItem(info, 'de')
        })

        it('Deletes languages', () => {

            configuration.deleteItem(info, 'cs')
            configuration.deleteAllItems(info)
        })        
    })

    describe('Default language', () => {

        const info = confInfo["default language"]

        it('Adds language', () => {

            //select
            configuration.selectLanguage('en')

        })

        it('Deletes languages', () => {

            configuration.deleteItem(info, 'en')
        })        
    })

    describe('Type of cooperation', () => {
        
        const info = confInfo["cooperation"]

        it('Adds cooperation type', () => {

            configuration.addItem(info, 'Part-time')
            configuration.addItem(info, 'Full-time')
        })

        it('Deletes cooperation type', () => {

            configuration.deleteItem(info, 'Part-time')
            configuration.deleteAllItems(info)
        })      
    })

    describe('Contract types', () => {

        const info = confInfo["contract"]

        it('Adds contract type', () => {

            configuration.addItem(info, 'Employee')
            configuration.addItem(info, 'Contractor')
            configuration.addItem(info, 'Intern')
        })

        it('Deletes contract type', () => {

            configuration.deleteItem(info, 'Contractor')
            configuration.deleteAllItems(info)
        }) 
    })

    describe('Currencies', () => {

        const info = confInfo["currencies"]

        it('Adds currencies', () => {

            configuration.addItem(info, 'CZK')
            configuration.addItem(info, 'PLN')
            configuration.addItem(info, 'USD')
        })

        it('Deletes currencies', () => {

            configuration.deleteItem(info, 'PLN')
            configuration.deleteAllItems(info)
        }) 
    })

    describe('Inventory types', () => {

        const info = confInfo["inventories"]

        it('Adds inventory type', () => {

            configuration.addItem(info, 'Car')
            configuration.addItem(info, 'Laptop')
        })

        it('Deletes inventory type', () => {

            configuration.deleteItem(info, 'Laptop')
            configuration.deleteAllItems(info)
        }) 
    })

    describe('Inventory conditions', () => {

        const info = confInfo["conditions"]

        it('Adds inventory type', () => {

            configuration.addItem(info, 'New')
            configuration.addItem(info, 'In repair')
        })

        it('Deletes inventory type', () => {

            configuration.deleteItem(info, 'In repair')
            configuration.deleteAllItems(info)
        }) 
    })

    describe('Working days', () => {

        it('Select working days', () => {

            configuration.selectWorkingDays([0, 1, 2, 5, 6])
        })

        it('Deselects working days', () => {

            configuration.deselectWorkingDays([0, 2])
            configuration.deselectWorkingDaysAll()
        }) 
    })

    describe('Select holidays', () => {

        it('Select holidays', () => {

            configuration.selectHolidays('24.05.2022')
        })

        it('Deselects holidays', () => {

            configuration.deselectHolidays('24.05.2022')
        }) 
    })

}

export function randomConfiguration() {

    describe('Random configuration', () => {

        it('Adds configuration', () => {

            configuration.addItem(confInfo["currencies"], 'CZK')
            configuration.addItem(confInfo["contract"], 'Contractor')
            configuration.addItem(confInfo["currencies"], 'EUR')
            configuration.addItem(confInfo["cooperation"], 'Part-time')
            configuration.addItem(confInfo["contract"], 'Intern')
            configuration.addItem(confInfo["cooperation"], 'Full-time')
            configuration.addItem(confInfo["conditions"], 'New')
            configuration.addItem(confInfo["global tags"], 'IT')
            configuration.addItem(confInfo["inventories"], 'Car')
            configuration.addItem(confInfo["inventories"], 'Laptop')
            configuration.addItem(confInfo["currencies"], 'USD')
            configuration.selectWorkingDays([1, 4, 5, 6])
            configuration.addItem(confInfo["global tags"], 'HR')
            configuration.addItem(confInfo["languages"], 'cs')
            configuration.addItem(confInfo["default language"], 'en')
            configuration.addItem(confInfo["conditions"], 'In repair')
            configuration.addItem(confInfo["global tags"], 'Marketing')
            configuration.addItem(confInfo["global tags"], 'Product')
            configuration.addItem(confInfo["languages"], 'en')
            configuration.selectHolidays('24.12.2022')
        })
    })
}

export function deleteRandomConfiguration() {

    describe('Delete random configuration', () => {
        it('Deletes configuration', () => {

            configuration.deleteAllItems(confInfo["contract"])
            configuration.deleteItem(confInfo["currencies"], 'CZK')
            configuration.deleteItem(confInfo["currencies"], 'EUR')
            configuration.deleteAllItems(confInfo["cooperation"])
            configuration.deselectWorkingDays([4])
            configuration.deleteAllItems(confInfo["currencies"])
            configuration.deleteItem(confInfo["languages"], 'en')
            configuration.deleteAllItems(confInfo["languages"])
            configuration.deselectWorkingDaysAll()
            configuration.deleteAllItems(confInfo["global tags"])
            configuration.deselectHolidays('24.12.2022')
            configuration.deleteAllItems(confInfo["inventories"])
            configuration.deleteAllItems(confInfo["conditions"])
        }) 
    })
}
