import * as charts from "../../../support/testFunctions/settings/charts"
import * as data from "../../../fixtures/data"
import * as employee from '../../../support/testFunctions/employee/employees'
import * as position from '../../../support/testFunctions/employee/position'

export function orgChart() {

    describe('Organisation chart', () => {
        
        beforeEach(() => {

            cy.visit('/settings/organisation-chart')
            cy.get('#mainContent > div.login-spinner').should('not.exist')
        })

        describe('Position', () => {

            it('Adds positions', () => {

                cy.get('h1:contains("Org chart")').should('be.visible')

                charts.addItem('QA Tester')
                charts.addItem('PHP Developer')
                charts.addItem('Manager')
            })

            it('Renames positions', () => {

                cy.get('h1:contains("Org chart")').should('be.visible')

                charts.renameItem('Manager', 'IT Manager')
                charts.renameItem('PHP Developer', 'Senior PHP developer')
            })

            it('Deletes positions', () => {

                cy.get('h1:contains("Org chart")').should('be.visible')

                charts.deleteItem('IT Manager')
                charts.deleteItem('Senior PHP developer')
                charts.deleteItem('QA Tester')
            })
        })

        describe('Employee', () => {

            it('Adds position to org chart', () => {

                cy.get('h1:contains("Org chart")').should('be.visible')

                charts.addItem(data.position[2].name)
            })

            it('Adds employee to position', () => {

                charts.addEmployeeToPosition(data.person[0], data.position[2])
            })

            it('Deletes employee from position', () => {

                cy.visit('/employees')
                cy.get('#mainContent > div.login-spinner').should('not.exist')

                employee.openEmployeeCard(data.person[0].surname)
                position.deletePosition(data.position[2].name)
                
                cy.visit('/settings/organisation-chart')
                cy.get('#mainContent > div.login-spinner').should('not.exist')

                charts.deleteItem(data.position[2].name)
            })
        })
    })
}