import * as template from "../../../support/testFunctions/templates"
import * as set from "../../../support/testFunctions/set_up"
import * as data from "../../../fixtures/data" 

describe('Templates', () => {

    beforeEach(() => {

        cy.visit('/templates')
        cy.get('#mainContent > div.login-spinner').should('not.exist')
    })

    describe('Sets up workspace', () => {
        
        set.setConfiguration()
        
        set.setCharts()
        
        set.createContents()
    })

    describe('Templates', () => {
        it('Creates a new template', () => {

            template.createTemplate('template#1', 'amazing temp')
        })

        it('Renames template', () => {

            template.renameTemplate('template#1', 'testing_template_new', 'newDesc')
        })

        it('Delete initial milestones', () => {

            template.openTemplate('testing_template_new')

            template.deleteModule('PREBOARDING')
            template.deleteModule('ONBOARDING')
        })

        it('Creates a milestone', () => {

            template.openTemplate('testing_template_new')

            template.addModule('PREBOARDING', true)
        })

        it('Creates a section', () => {

            template.openTemplate('testing_template_new')
            template.openModule('PREBOARDING')

            template.addPhase('section_name')
        })

        it('Renames section', () => {

            template.openTemplate('testing_template_new')
            template.openModule('PREBOARDING')

            template.renamePhase('section_name', 'section_me')
        })

        it('Creates an empty task and internal task', () => {

            template.openTemplate('testing_template_new')
            template.openModule('PREBOARDING')

            template.addTask('task_name', 'description', true)
            template.addInternalTask('task_name', 'description', 'internal_name', data.content[0])
        })

        it('Renames task and internal task', () => {

            template.openTemplate('testing_template_new')
            template.openModule('PREBOARDING')

            template.renameInternalTask('task_name', 'internal_name', 'new_internal')
        })

        it('Creates a task', () => {

            template.openTemplate('testing_template_new')
            template.openModule('PREBOARDING')

            template.addTask('task_with_content_name', 'description', true, data.content[0])
        })

        it('Deletes internal task and task', () => {

            template.openTemplate('testing_template_new')
            template.openModule('PREBOARDING')

            template.deleteInternalTask('task_name')
            template.deleteTask('task_name')
        })

        it('Deletes section', () => {

            template.openTemplate('testing_template_new')
            template.openModule('PREBOARDING')
            
            template.deletePhase('section_me')
        })

        it('Deletes milestone', () => {

            template.openTemplate('testing_template_new')
            template.openModule('PREBOARDING')

            template.deleteModule('PREBOARDING')
        })

        it('Deletes template', () => {

            template.openTemplate('testing_template_new')

            template.deleteTemplate('testing_template_new')
        })
    })

    describe('Cleans up workspace after tests', () => {

        set.deleteContents()
        
        set.deleteConfiguration()
    })
})