import * as data from "../../../fixtures/data"
import * as content from "../../../support/testFunctions/content"
import * as set from "../../../support/testFunctions/set_up"

describe('Wiki/Content', () => {

    beforeEach(() => {

        cy.visit('/content')
        cy.get('#mainContent > div.login-spinner').should('not.exist')
    })

    describe('Sets up workspace', () => {
        
        set.setConfiguration()
    })

    describe('Content', () => {
        it('Creates a new content', () => {

            content.createContent('CONTENTcontent', 'content')
        })

        it('Creates segment - content', () => {

            content.openContent('CONTENTcontent')
            content.createSegment('CONTENT_content', 'Content')
            content.fillContentLong()
        })

        it('Checks preview', () => {

            content.openContent('CONTENTcontent')
            content.openPrev()
            content.previewContentLong()
            content.closePrev()
        })

        it('Deletes segment', () => {

            content.openContent('CONTENTcontent')
            content.deleteSegment('CONTENT_content')
        })

        it('Deletes a content', () => {

            content.openContent('CONTENTcontent')
            content.deleteContent('CONTENTcontent', 'content')
        })
    })

    describe('Quiz', () => {
        it('Creates a new content', () => {

            content.createContent('CONTENTquiz', 'content')
        })

        it('Creates segment - quiz', () => {

            content.openContent('CONTENTquiz')
            content.createSegment('CONTENT_quiz', 'Quiz')
            content.createQuizElements('CONTENT_quiz')
        })

        it('Checks preview', () => {

            content.openContent('CONTENTquiz')
            content.openPrev()
            content.closePrev()
        })

        it('Deletes segment', () => {

            content.openContent('CONTENTquiz')
            content.deleteSegment('CONTENT_quiz')
        })

        it('Deletes a content', () => {

            content.openContent('CONTENTquiz')
            content.deleteContent('CONTENTquiz', 'content')
        })
    })

    describe('Form', () => {
        it('Creates a new content', () => {

            content.createContent('CONTENTform', 'content')
        })

        it('Creates segment - form', () => {

            content.openContent('CONTENTform')
            content.createSegment('CONTENT_form', 'Form')
            content.createCustomForm('CONTENTform')
        })

        it('Checks preview', () => {

            content.openContent('CONTENTform')
            content.openPrev()
            content.previewFormCustom()
            content.closePrev()
        })

        it('Deletes segment', () => {

            content.openContent('CONTENTform')
            content.deleteSegment('CONTENT_form')
        })

        it('Deletes a content', () => {

            content.openContent('CONTENTform')
            content.deleteContent('CONTENTform', 'content')
        })
    })

    describe('Files', () => {
        it('Creates a new content', () => {

            content.createContent('CONTENTfiles', 'content')
        })

        it('Creates segment - files', () => {

            content.openContent('CONTENTfiles')
            content.createSegment('CONTENT_files', 'List of files')
            content.addFiles(data.files)
        })

        it('Checks preview', () => {

            content.openContent('CONTENTfiles')
            content.openPrev()
            content.previewFiles(data.files)
            content.closePrev()
        })

        it('Deletes files', () => {

            content.openContent('CONTENTfiles')
            content.deleteFiles(data.files)
        })

        it('Deletes segment', () => {

            content.openContent('CONTENTfiles')
            content.deleteSegment('CONTENT_files')
        })

        it('Deletes a content', () => {

            content.openContent('CONTENTfiles')
            content.deleteContent('CONTENTfiles', 'content')
        })

    })

    describe('Video', () => {
        it('Creates a new content', () => {

            content.createContent('CONTENTvideo', 'content')
        })

        it('Creates segment - video', () => {

            content.openContent('CONTENTvideo')
            content.createSegment('CONTENT_video', 'Video')
            content.addYoutube('M_k0mil4IPs')
        })

        it('Deletes segment', () => {

            content.openContent('CONTENTvideo')
            content.deleteSegment('CONTENT_video')
        })

        it('Deletes a content', () => {

            content.openContent('CONTENTvideo')
            content.deleteContent('CONTENTvideo', 'content')
        })
    })

    describe('Notion', () => {
        it('Creates a new content', () => {

            content.createContent('CONTENTnotion', 'content')
        })

        it('Creates segment - notion', () => {

            content.openContent('CONTENTnotion')
            content.createSegment('CONTENT_notion', 'Notion')
        })

        it('Deletes segment', () => {

            content.openContent('CONTENTnotion')
            content.deleteSegment('CONTENT_notion')
        })

        it('Deletes a content', () => {

            content.openContent('CONTENTnotion')
            content.deleteContent('CONTENTnotion', 'content')
        })
    })

    describe('Cleans up workspace after tests', () => {
        
        set.deleteConfiguration()
    })
})