import * as employee from "../../support/testFunctions/employee/employees"
import * as set from "../../support/testFunctions/set_up"
import * as data from "../../fixtures/data"
import * as onboarding from "../../support/testFunctions/onboarding"
import * as template from "../../support/testFunctions/templates"
import * as position from "../../support/testFunctions/employee/position"

describe('Admin account', () => {

    describe('Sets up workspace', () => {
        
        set.setConfiguration()
        
        set.setCharts()
        
        set.createContents()
        
        set.addEmployees()
        
        set.createUser()
    })

    describe('Onboarding using career', () => {
        
        it('Adds new milestone and section', () => {

            cy.visit('/employees')
            cy.get('#mainContent > div.login-spinner').should('not.exist')
            employee.openEmployeeCard(data.person[0].surname)
            employee.openTab('Career')

            template.addModule('PROMOTION', false)
            template.openModule('PROMOTION')

            template.addPhase('new section')
        })

        it('Adds new tasks', () => {

            cy.visit('/employees')
            cy.get('#mainContent > div.login-spinner').should('not.exist')
            employee.openEmployeeCard(data.person[0].surname)
            employee.openTab('Career')
            template.openModule('PROMOTION')

            template.addTask('task0', 'new task desc', false, data.content[0])
            template.addTask('task2', 'new task desc', false, data.content[2])
            template.addTask('task8', 'new task desc', false, data.content[8])
        })

        it('Changes status of the position', () => {

            cy.visit('/employees')
            cy.get('#mainContent > div.login-spinner').should('not.exist')
            employee.openEmployeeCard(data.person[0].surname)
            position.changePositionStatus()
        })
    })
})

describe('Employee account', () => {

    before(() => {

        Cypress.session.clearAllSavedSessions()
    })
    
    beforeEach(() => {
        
        cy.login_session(data.user[0].email, data.user[0].password)
        cy.visit('/')
    })

    describe('Legal content', () => {
        it('Confirms legal content', () => {

            employee.confirmLegalContent() 
        })
    })

    describe('My career', () => {

        it('Open my onboarding and milestone', () => {

            onboarding.openModule('PROMOTION')

            onboarding.openTask('task0')
            onboarding.changeTaskState('task0', 'Rejected')

            onboarding.openTask('task0')
            onboarding.completeTask('task0', 'form')

            onboarding.openTask('task2')
            onboarding.changeTaskState('task2', 'Inprogress')
        })
    })
})

describe('Admin account', () => {

    before(() => {

        Cypress.session.clearAllSavedSessions()
    })
    
    beforeEach(() => {
        
        cy.login_sesh()
    })

    describe('Cleans up workspace after tests', () => {

        set.deleteUser()
        
        set.deleteEmployees()
        
        set.deleteContents()
        
        set.deleteConfiguration()
    })
})