import * as employee from "../../support/testFunctions/employee/employees"
import * as set from "../../support/testFunctions/set_up"
import * as template from "../../support/testFunctions/templates"
import * as data from "../../fixtures/data"

describe('Admin account', () => {

    describe('Sets up workspace', () => {

        set.setConfiguration()
        
        set.setCharts()
        
        set.createContents()
        
        set.addEmployees()
        
        set.createUser()
    })

    describe('Onboarding using career', () => {
        
        it('Adds new milestone and section', () => {

            cy.visit('/employees')
            cy.get('#mainContent > div.login-spinner').should('not.exist')
            employee.openEmployeeCard(data.person[1].surname)
            employee.openTab('Career')

            template.addModule('PROMOTION', false)
            template.openModule('PROMOTION')

            template.addPhase('new section')
        })

        it('Adds new tasks', () => {

            cy.visit('/employees')
            cy.get('#mainContent > div.login-spinner').should('not.exist')
            employee.openEmployeeCard(data.person[1].surname)
            employee.openTab('Career')
            template.openModule('PROMOTION')

            template.addTask('task0', 'new task desc', false, data.content[0])
            template.addInternalTask('task0', 'description', 'internal_name0', data.content[0], data.person[0].surname)
        })
    })
})

describe('Employee account', () => {

    before(() => {

        Cypress.session.clearAllSavedSessions()
    })
    
    beforeEach(() => {
        
        cy.login_session(data.user[0].email, data.user[0].password)
        cy.visit('/my-tasks/')
        cy.get('#mainContent > div.login-spinner').should('not.exist')
    })

    describe('Legal content', () => {
        it('Confirms legal content', () => {

            employee.confirmLegalContent() 
        })
    })

    describe('Personal information', () => {

        it('Check team tasks', () => {

            employee.checkAssignedTasks(['internal_name0'])
        })
    })
})

describe('Admin account', () => {

    before(() => {

        Cypress.session.clearAllSavedSessions()
    })
    
    beforeEach(() => {
        
        cy.login_sesh()
    })

    describe('Cleans up workspace after tests', () => {

        set.deleteUser()
        
        set.deleteEmployees()
        
        set.deleteContents()
        
        set.deleteConfiguration()
    })
})