import * as employee from "../../support/testFunctions/employee/employees"
import * as position from "../../support/testFunctions/employee/position"
import * as setUser from "../../support/testFunctions/settings/roles"
import * as set from "../../support/testFunctions/set_up"
import * as data from "../../fixtures/data"

describe('Admin account', () => {

    describe('Sets up workspace', () => {
        
        set.setConfiguration()
        
        set.setCharts()
        
        set.addEmployees()
        
        set.createUser()
    })
})

describe('Employee account without a linked employee', () => {

    before(() => {

        Cypress.session.clearAllSavedSessions()
    })
    
    beforeEach(() => {
        
        cy.login_session(data.user[0].email, data.user[0].password)
        cy.visit('/profile/personal-information/')
        cy.get('#mainContent > div.login-spinner').should('not.exist')
    })

    describe('Legal content', () => {
        it('Confirms legal content', () => {

            employee.confirmLegalContent() 
        })
    })

    describe('Account', () => {

        it('Checks there is nothing to be seen', () => {

            // employee.checkNavTabs(false)
        })
    })
})

describe('Admin account', () => {

    before(() => {

        Cypress.session.clearAllSavedSessions()
    })
    
    beforeEach(() => {
        
        cy.login_sesh()
    })

    describe('Sets up workspace', () => {

        it('Creates user', () => {

            cy.visit('/settings/users')
            cy.get('#mainContent > div.login-spinner').should('not.exist')
            setUser.linkAccount(data.user[0], data.person[0].surname)
        })
    })
})

describe('Employee account with a linked employee', () => {

    before(() => {

        Cypress.session.clearAllSavedSessions()
    })
    
    beforeEach(() => {
        
        cy.login_session(data.user[0].email, data.user[0].password)
        cy.visit('/profile/personal-information/')
        cy.get('#mainContent > div.login-spinner').should('not.exist')
    })

    describe('Account', () => {

        it('Checks tabs that are supposed to be there', () => {

            employee.checkNavTabs(true)
        })
    })

    describe('Personal information', () => {

        it('Changes personal information', () => {

            employee.changePersonalInfo(data.person[4])
            employee.checkChangedPersonalInfo(data.person[4])
        })
    })

    describe('Position', () => {
        
        it('Checks if position info is disabled', () => {

            position.checkDisabled()
        })
    })

    describe('Language', () => {
        
        it('Changes language to cs', () => {

            employee.openTab('Language')
            employee.changeLanguage('cs')
        })

        it('Changes language back to en', () => {
 
            employee.openTab('Language')
            employee.changeLanguage('en')
        })
    })
})

describe('Admin account', () => {

    before(() => {

        Cypress.session.clearAllSavedSessions()
    })
    
    beforeEach(() => {
        
        cy.login_sesh()
    })

    describe('Cleans up workspace after tests', () => {

        set.deleteUser()
        
        set.deleteEmployees()
        
        set.deleteConfiguration()
    })
})