import 'cypress-file-upload';

// ***********************************************
// This example commands.js shows you how to
// create various custom commands and overwrite
// existing commands.
//
// For more comprehensive examples of custom
// commands please read more here:
// https://on.cypress.io/custom-commands
// ***********************************************
//
//
// -- This is a parent command --
// Cypress.Commands.add('login', (email, password) => { ... })
//
//
// -- This is a child command --
// Cypress.Commands.add('drag', { prevSubject: 'element'}, (subject, options) => { ... })
//
//
// -- This is a dual command --
// Cypress.Commands.add('dismiss', { prevSubject: 'optional'}, (subject, options) => { ... })
//
//
// -- This will overwrite an existing command --
// Cypress.Commands.overwrite('visit', (originalFn, url, options) => { ... })

/**
 * Logs in the application using cy.session() with given account information
 * 
 * @param {string} username account username
 * @param {string} password account password
 */
Cypress.Commands.add('login_session', (username, password) => {
    cy.session([username, password], () => {
        cy.intercept('GET', '/_timesync').as('alias')
        cy.intercept('GET', '/sockjs/info?**').as('alias2') 

        let workspaceName

        if (Cypress.env('WORKSPACE_NAME')) {
           workspaceName = Cypress.env('WORKSPACE_NAME')
        } else {
            workspaceName = 'test' + Math.floor(100000 + Math.random() * 900000)
        }

        cy.config('baseUrl', 'https://' + workspaceName + '.onbee.link/')

        Cypress.env('WORKSPACE_NAME', workspaceName)

        cy.visit('/login')
        cy.url().should('equal', 'https://app.onbee.link/login/')

        cy.get('[name="username"]').type(username)
        cy.get('[name="password"]').type(password)
        cy.get('form [type="submit"]').click()

        cy.url().should('contain', Cypress.config('baseUrl')).then(() => {

            cy.wait('@alias2').its('response.statusCode').should('be.greaterThan', 199).and('be.lessThan', 303)
            cy.wait('@alias').its('response.statusCode').should('be.greaterThan', 199).and('be.lessThan', 303)
            
            cy.get('svg.object-contain').should('exist').and('be.visible')
        })
    })
})

/**
 * Logs in the application using cy.session() - login username is generated from the name of the workspace
 */
Cypress.Commands.add('login_sesh', () => {
    cy.session('login_session', () => {
        cy.intercept('GET', '/_timesync').as('alias')
        cy.intercept('GET', '/sockjs/info?**').as('alias2') 

        let workspaceName

        if (Cypress.env('WORKSPACE_NAME')) {
           workspaceName = Cypress.env('WORKSPACE_NAME')
        } else {
            workspaceName = 'test' + Math.floor(100000 + Math.random() * 900000)
        }

        cy.config('baseUrl', 'https://' + workspaceName + '.onbee.link/')

        Cypress.env('WORKSPACE_NAME', workspaceName)

        cy.visit('/login')
        cy.url().should('equal', 'https://app.onbee.link/login/')

        // TODO intentional missing part of the code -3-
        cy.get('[name="username"]').type('')
        // TODO intentional missing part of the code -4-
        cy.get('[name="password"]').type('')
        cy.get('form [type="submit"]').click()

        cy.url().should('contain', Cypress.config('baseUrl')).then(() => {
            cy.wait('@alias2').its('response.statusCode').should('be.greaterThan', 199).and('be.lessThan', 303)
            cy.wait('@alias').its('response.statusCode').should('be.greaterThan', 199).and('be.lessThan', 303)
            
            cy.get('svg.object-contain').should('exist').and('be.visible')
        })
    })
})

/**
 * Selects given option in selectbox of a given name 
 * 
 * @param {string} selectName label of the select box
 * @param {string} optionName name of the wanted option
 */
Cypress.Commands.add('selectOption', (selectName, optionName) => {
    cy.get('label:contains("' + selectName + '") + ').last().click()
    cy.get('.selectTw__menu-list').should('be.visible')
    cy.get('.selectTw__option:contains("' + optionName + '")').should('exist').click()
    cy.get('label:contains("' + selectName + '"):last ~ div, .selectTW__single-value').should('contain', optionName)
})

/**
 * Clicks on a delete button of a given name and comfirms deletion
 * 
 * @param {string} deleteButtonName text in the delete button
 */
Cypress.Commands.add('delete', (deleteButtonName) => {
    cy.get('button:contains("' + deleteButtonName + '")').click()
    cy.get('div[id^="headlessui-dialog-panel"]').should('be.visible')
    cy.get('button:contains("Confirm")').click()
})