import { statuses } from '../../../fixtures/data'

/**
 * Fills information of a position in a 'Add' employee form or when adding new position to a person's card
 *  
 * @param {object} position information about position that the person is being assigned to
 * @param {string} mode if the position is being picked from existing ones or is being created, has two options 'pick' and 'create'
 */
export function fillPositionInfo(position, mode='pick', template) {

    if (mode === 'pick') {

        cy.get('.group > .items-stretch > .pt-4 > .flex-col > .items-start > .flex.flex-grow > .flex > .inset-0').first().click()

    } else if (mode === 'create') {

        cy.get('button:contains("Create position")').click()
        cy.get('[name="name"]').type(position.name)

    }
    
    //filling position information common for both modes
    cy.get('[name="positionId"]').type(position.id)

    if (template) {
        cy.get('label:contains("Template") + div').type(position.template + '{enter}')
        cy.get('label:contains("Buddy") + div').type(position.buddy + '{enter}')
    } else {
        cy.get('label:contains("Skip preboarding & onboarding")').click()
    }
    
    cy.get('label:contains("Contract type") + div').type(position.contract + '{enter}')
    cy.get('label:contains("Type of cooperation") + div').type(position.cooperation + '{enter}')
    cy.get('label:contains("Start date") + div').type(position.start)
    cy.get('label:contains("End date") + div').type(position.end)
    cy.get('label:contains("Team leader") + div').type(position.team + '{enter}')
    // cy.get('label:contains("Position in geo chart") + div').type(position.geo + '{enter}')
    cy.selectOption('Position in geo chart', position.geo)
    cy.get('label:contains("Project chart") + div').type(position.project + '{enter}')
    cy.get('[name="fte"]').type(position.fte)
    cy.get('[name="payment"]').type(position.payment)
    cy.get('label:contains("Currency") + div').type(position.currency + '{enter}')
}

/**
 * Changes position status to a random status from the selection
 */
export function changePositionStatus() {

    let status = statuses[(Math.floor(Math.random() * 9))] 

    cy.get('button:contains("Change position status")').click()
    cy.get('label:contains("Status") + div').type(status + '{enter}')

    cy.get('button:contains("Change position status"):last').click()

    //check the changes
    cy.get('h2 + span').should('contain', status)
    cy.get('.Toastify > div').should('exist')
}

/**
 * Changes position information on the person's card
 * 
 * @param {string} positionName name of the position
 * @param {object} position information about position that the person is being assigned to 
 */
export function changePositionInfo(positionName, position) {

    cy.get('form h2:contains("'+positionName+'")').parent().parent().parent().parent().within(() => {

        cy.get('label:contains("Contract type") + div').type(position.contract + '{enter}')
        cy.get('label:contains("Type of cooperation") + div').type(position.cooperation + '{enter}')
        cy.get('label:contains("Start date") + div').clear().type(position.start)
        cy.get('label:contains("End date") + div').clear().type(position.end)
        cy.get('label:contains("Position in geo chart") + div').type(position.geo + '{enter}')
        cy.get('[name="positionId"]').clear().type(position.id)
        cy.get('label:contains("Team leader") + div').type(position.team + '{enter}')
        cy.get('label:contains("Buddy") + div').type(position.buddy + '{enter}')
        cy.get('[name="fte"]').clear().type(position.fte)
        cy.get('[name="payment"]').clear().type(position.payment)
        cy.get('label:contains("Currency") + div').type(position.currency + '{enter}')

        cy.get('button:contains("Save position")').click()

        // checks
        cy.get('label:contains("Contract type") + div').should('contain', position.contract)
        cy.get('label:contains("Type of cooperation") + div').should('contain', position.cooperation)
        cy.get('label:contains("Start date") + div input').should('have.value', position.start)
        cy.get('label:contains("End date") + div input').should('have.value', position.end)
        cy.get('label:contains("Position in geo chart") + div').should('contain', position.geo)
        cy.get('[name="positionId"]').should('have.value', position.id)
        cy.get('label:contains("Team leader") + div').should('contain', position.team)
        cy.get('label:contains("Buddy") + div').should('contain', position.buddy)
        cy.get('[name="fte"]').should('have.value', position.fte)
        cy.get('[name="payment"]').should('have.value', position.payment)
        cy.get('label:contains("Currency") + div').should('contain', position.currency)
    })
}

/**
 * Adds a person to a position on his personal card
 *  
 * @param {object} position information about position that the person is being assigned to
 * @param {string} mode if the position is being picked from existing ones or is being created, has two options 'pick' and 'create'
 */
export function addToPosition(position, mode) {

    cy.get('button:contains("Add new position")').click()
    cy.url().should('contain', 'add/workload')
    cy.get('#mainContent > div.login-spinner').should('not.exist')

    fillPositionInfo(position, mode)

    cy.get('button:contains("Create position")').click()

    cy.get('#mainContent > div.login-spinner').should('not.exist')
    cy.get('form').should('contain', position.name)
}

/**
 * Deletes the position of given name on the employee's card
 * 
 * @param {string} positionName name of the position to be deleted
 */
export function deletePosition(positionName) {

    cy.get('h2:contains("' + positionName + '")').parentsUntil('form').siblings().last().within(() => {
        cy.get('button:contains("Delete position")').click()

    })

    cy.get('div[id^="headlessui-dialog-panel"]').should('be.visible')
    cy.get('button:contains("Confirm")').click()

    // check
    cy.get('form').should('not.contain', positionName)
}

/**
 * Deletes the last position on the employee's card
 */
export function deleteLastPosition() {

    cy.delete('Delete position')

    // check
    cy.get('form').should('not.contain', positionName)
}


/**
 * Checks if the position informations are disabled on user's profile
 */
export function checkDisabled() {

    cy.get('form:last').within(() => {
        cy.get('label + div').should('have.length', 11).and('have.class', 'selectTw--is-disabled')
    })
}

export function changeTeamLeader(positionName, teamLeader) {

    cy.get('form h2:contains("'+positionName+'")').parent().parent().parent().parent().within(() => {

        cy.get('label:contains("Team leader") + div').type(teamLeader + '{enter}')

        cy.get('button:contains("Save position")').click()

        // checks
        cy.get('label:contains("Team leader") + div').should('contain', teamLeader)
    })
}