/**
 * Adds an inventory item to inventory
 * 
 * @param {object} item item object containing all needed info
 */
export function addInventoryItem(item) {

    cy.get('a:contains("Add")').click()

    // fill info
    cy.get('[name="name"]').type(item.name)
    cy.get('label:contains("Inventory type") + div').type(item.type + '{enter}')
    cy.get('[name="serialNumber"]').type(item.serialNum)
    cy.get('[name="inventoryNumber"]').type(item.inventoryNum)
    cy.get('[name="price"]').type(item.price)
    cy.get('label:contains("Currency") + div').type(item.currency + '{enter}')
    cy.get('label:contains("Condition") + div').type(item.condition + '{enter}')
    cy.get('label:contains("Date of purchase") + div').type(item.date + '{enter}')
    cy.get('[name="accessories"]').type(item.accessories)
    cy.get('[name="description"]').type(item.description)

    // save
    cy.get('button:contains("Save inventory")').click()

    //check
    cy.get('table > tbody tr').should('contain', item.name)
}


/**
 * Opens up inventory item's detail
 * 
 * @param {string} itemName name of the inventory item
 */
export function openInventoryDetail(itemName) {

    cy.get('td:contains("' + itemName + '")').click()
    // cy.url().should('contain', '/inventory-detail')
}

/**
 * Changes inventory item's details
 * 
 * @param {object} item item object containing all needed info
 */
export function changeInventoryInfo(item) {

    cy.get('[name="name"]').clear().type(item.name)
    cy.get('label:contains("Inventory type") + div').type(item.type + '{enter}')
    cy.get('[name="serialNumber"]').clear().type(item.serialNum)
    cy.get('[name="inventoryNumber"]').clear().type(item.inventoryNum)
    cy.get('[name="price"]').clear().type(item.price)
    cy.get('label:contains("Currency") + div').type(item.currency + '{enter}')
    cy.get('label:contains("Condition") + div').type(item.condition + '{enter}')
    cy.get('label:contains("Date of purchase") + div').type(item.date + '{enter}')
    cy.get('[name="accessories"]').clear().type(item.accessories)
    cy.get('[name="description"]').clear().type(item.description)

    cy.get('button:contains("Save inventory")').click()

    cy.get('table').should('contain', item.name)

}

export function delInventoryItem(itemName) {

    cy.get('button:contains("Delete")').click()
    cy.get('button:contains("Confirm")').click()

    cy.visit('/inventory')
    cy.get('table').should('not.contain', itemName)

}

export function assignItem(itemName) {

    cy.get('button:contains("Add inventory")').click()
    cy.wait(2000)
    cy.selectOption('Inventory', itemName)
    cy.get('button:contains("Assign inventory to this employee")').click()

    cy.get('table').should('contain', itemName)
}

export function unassignItem(itemName) {
 
    cy.get('button:contains("Remove inventory")').click()
    cy.get('button:contains("Confirm")').click()

    cy.get('table').should('not.contain', itemName)
}

export function checkAssignedItem(itemName, personSurname) {

    cy.wait(2000)
    cy.get('td:contains("'+itemName+'") ++++').should('contain', 'ASSIGNED')
    cy.get('td:contains("'+itemName+'") +++++').should('contain', personSurname)
    
}

export function checkUnassignedItem(itemName) {

    cy.wait(2000)
    cy.get('td:contains("'+itemName+'") ++++').should('contain', 'AVAILABLE')
    cy.get('td:contains("'+itemName+'") +++++').should('contain', '')
    
}