/**
 * Opens onboarding of given person
 * 
 * @param {object} person object of a person with all information
 */
export function openOnboarding(person) {

    cy.wait(25000)
    cy.get('td:contains("' + person.surname + '")').first().click()
    cy.url().should('contain', '/onboarding-detail')
}

/**
 * Opens milestone of given name
 * 
 * @param {string} milestoneName name of the milestone
 */
export function openModule(milestoneName) {

    cy.get('div > div > h4:contains("'+ milestoneName +'")').parent().as('btn').click()
    cy.get('@btn').should('have.class', 'shadow')
}

/**
 * Opens task of given name
 * 
 * @param {string} taskName name of the task
 */
export function openTask(taskName) {

    cy.get('div[role="button"]:contains("'+taskName+'")').click()
    cy.get('div[id^=headlessui-dialog-panel]').should('be.visible')
}

/**
 * Changes task status using the status button
 * 
 * @param {string} taskName name of the task
 * @param {string} endState the wanted end status of the task - possible options are 'Inprogress' and 'Rejected'
 */
export function changeTaskState(taskName, endState) {

    cy.get('form button:first').click()
    cy.get('ul').should('be.visible')
    cy.get('li:contains("' + endState + '")').should('exist').click()

    cy.get('div[id^=headlessui-dialog-panel]').should('not.be.exist')

    cy.get('div[role="button"]:contains("'+ taskName +'")').parent().parent().parent().siblings().first().should('contain', endState)
}

/**
 * Changes task status to 'DONE'
 * 
 * @param {string} taskName name of the task
 * @param {string} taskType type of the content inside the task - options are form/upload/content/file/video/quiz/document/notion/inventory
 */
export function completeTask(taskName, taskType) {

    // missing notion and inventory
    switch (taskType) {
        case 'form':
            cy.get('button:contains("Submit")').click()
            break
        case 'upload':
        case 'content':
        case 'file':
        case 'video':
            cy.get('button:contains("Got it, submit!")').click()
            break
        case 'quiz':
            cy.get('button:contains("Start quiz")').click()
            cy.get('button:contains("Submit quiz")').click()
            break
        case 'document':
            cy.get('button:contains("Send SMS")').click()
            // fill sms code
            cy.get('button:contains("Validate")').click()
            break
    }

    cy.get('div[id^=headlessui-dialog-panel]').should('not.be.exist')
    cy.get('div[role="button"]:contains("'+ taskName +'")').parent().parent().parent().siblings().first().should('contain', 'Done')
}



