import * as data from "../../fixtures/data"
import { item, person, user } from "../../fixtures/data"
import * as configuration from "../../support/testFunctions/settings/configuration"
import * as files from "../../support/testFunctions/settings/files"
import * as employee from "../../support/testFunctions/employee/employees"
import * as position from "../../support/testFunctions/employee/position"
import * as content from "../../support/testFunctions/content"
import * as template from "../../support/testFunctions/templates"
import { confInfo } from "../../support/testFunctions/settings/configuration"
import { deleteItem } from "./settings/charts"
import * as keyrole from "./settings/keyroles_and_custom_fields"
import * as inventory from "./inventory"
import * as setUser from "../../support/testFunctions/settings/roles"
import * as charts from "./settings/charts"


// configuration
export function setConfiguration() {

    it('Sets configuration', () => {
        cy.visit('/settings/configurations')
        cy.get('#mainContent > div.login-spinner').should('not.exist')

        configuration.addItem(confInfo["global tags"], 'IT')
        configuration.addItem(confInfo["global tags"], 'HR')
        configuration.addItem(confInfo["global tags"], 'Marketing')
        configuration.addItem(confInfo["global tags"], 'Product')
    
        configuration.addItem(confInfo["languages"], 'cs')
        configuration.addItem(confInfo["languages"], 'en')

        configuration.addItem(confInfo["default language"], 'en')
    
        configuration.addItem(confInfo["cooperation"], 'Part-time')
        configuration.addItem(confInfo["cooperation"], 'Full-time')
    
        configuration.addItem(confInfo["contract"], 'Contractor')
        configuration.addItem(confInfo["contract"], 'Employee')
    
        configuration.addItem(confInfo["currencies"], 'USD')
        configuration.addItem(confInfo["currencies"], 'EUR')
        configuration.addItem(confInfo["currencies"], 'CZK')
    
        configuration.addItem(confInfo["inventories"], 'Car')
        configuration.addItem(confInfo["inventories"], 'Laptop')
    
        configuration.addItem(confInfo["conditions"], 'New')
        configuration.addItem(confInfo["conditions"], 'In repair')

        configuration.selectWorkingDays([1, 5, 6])

        configuration.selectHolidays('23.05.2022') 

    })
}

export function deleteConfiguration() {

    it('Deletes configuration', () => {
        cy.visit('/settings/configurations')
        cy.get('#mainContent > div.login-spinner').should('not.exist')

        configuration.deleteAllItems(confInfo["global tags"])
        configuration.deleteAllItems(confInfo["languages"])
        configuration.deleteAllItems(confInfo["cooperation"])
        configuration.deleteAllItems(confInfo["contract"])
        configuration.deleteAllItems(confInfo["currencies"])
        configuration.deleteAllItems(confInfo["inventories"])
        configuration.deleteAllItems(confInfo["conditions"])

        configuration.deselectWorkingDaysAll()

        configuration.deselectHolidays('23.05.2022')
    })
}

// employee
export function addEmployees() {

    it('Adds employees without templates: Add employee 1', () => {
        cy.visit('/employees')
        cy.get('#mainContent > div.login-spinner').should('not.exist')

        employee.addEmployee(person[0], data.position[0], 'create', false)
    })

    it('Adds employees without templates: Add employee 2', () => {
        cy.visit('/employees')
        cy.get('#mainContent > div.login-spinner').should('not.exist')

        employee.addEmployee(person[1], data.position[1], 'create', false)
    })
}

export function addEmployeesWithTemplate() {

    it('Adds employees with templates: Add employee 1', () => {
        cy.visit('/employees')
        cy.get('#mainContent > div.login-spinner').should('not.exist')

        employee.addEmployee(person[0], data.position[0], 'create', true)
    })

    it('Adds employees with templates: Add employee 2', () => {
        cy.visit('/employees')
        cy.get('#mainContent > div.login-spinner').should('not.exist')

        employee.addEmployee(person[1], data.position[1], 'create', true)
    })
}

export function deleteEmployees() {

    it('Deletes employees: Deletes employee 1', () => {
        cy.visit('/employees')
        cy.get('#mainContent > div.login-spinner').should('not.exist')

        employee.openEmployeeCard(data.person[0].surname)
        position.deletePosition(data.position[0].name)
        employee.deleteEmployee(data.person[0].surname)
    })

    it('Deletes employees: Deletes employee 2', () => {
        cy.visit('/employees')
        cy.get('#mainContent > div.login-spinner').should('not.exist')

        employee.openEmployeeCard(data.person[1].surname)
        position.deletePosition(data.position[1].name)
        employee.deleteEmployee(data.person[1].surname)
    })

    it('Deletes employees: Deletes positions in org chart', () => {
        cy.visit('/settings/organisation-chart')

        deleteItem(data.position[0].name)
        deleteItem(data.position[1].name)
    })
}

// content
export function createContents() {
 
    it('Creates contents: Creates contents', () => {
        cy.visit('/content')
        cy.get('#mainContent > div.login-spinner').should('not.exist')

        content.createContent('0 form', 'form')
        content.openContent('0 form')
        content.createSegment('form', 'Form')
        content.createCustomForm('0 form')
  
        cy.visit('/content')
        cy.get('#mainContent > div.login-spinner').should('not.exist')

        content.createContent('1 upload', 'form')
        content.openContent('1 upload')
        content.createSegment('upload file from onbee', 'Upload files')
        
        cy.visit('/content')
        cy.get('#mainContent > div.login-spinner').should('not.exist')

        content.createContent('2 content', 'content')
        content.openContent('2 content')
        content.createSegment('content for onbee', 'Content')
        content.fillContentShort()

        cy.visit('/content')
        cy.get('#mainContent > div.login-spinner').should('not.exist')
    
        content.createContent('8 signature', 'document', 'Document for signing')
        content.openContent('8 signature')
        content.fillContentDoc()
    })
}

export function createContentsForWiki() {

   it('Creates contents and keeps them in Wiki: Creates content', () => {
        cy.visit('/content')

        content.createContent('2 content', 'content')
        content.openContent('2 content')
        content.createSegment('content for onbee', 'Content')
        content.fillContentShort()
        content.keepInWiki()
    })
    
    it('Creates contents and keeps them in Wiki: Creates quiz', () => {
        cy.visit('/content')

        content.createContent('3 quiz', 'content')
        content.openContent('3 quiz')
        content.createSegment('quiz for onbee', 'Quiz')
        content.createQuizElements('3 quiz')
        content.keepInWiki()
    })

    it('Creates contents and keeps them in Wiki: Creates form', () => {
        cy.visit('/content')
    
        content.createContent('4 form', 'content')
        content.openContent('4 form')
        content.createSegment('form2 for onbee', 'Form')
        content.createCustomForm('4 form')
        content.keepInWiki()
    })

    it('Creates contents and keeps them in Wiki: Creates list of files', () => {
        cy.visit('/content')
    
        content.createContent('5 files', 'content')
        content.openContent('5 files')
        content.createSegment('files for onbee', 'List of files')
        content.keepInWiki()
    })

    it('Creates contents and keeps them in Wiki: Creates video', () => {
        cy.visit('/content')
    
        content.createContent('6 video', 'content')
        content.openContent('6 video')
        content.createSegment('video for onbee', 'Video')
        content.keepInWiki()
    })

    it('Creates contents and keeps them in Wiki: Creates notion', () => {
        cy.visit('/content')
    
        content.createContent('7 notion', 'content')
        content.openContent('7 notion')
        content.createSegment('notion content for onbee', 'Notion')
        content.keepInWiki()
    })  
}

export function deleteContents() {

    it('Deletes created contents', () => {
        cy.visit('/content')

        content.openContent('0 form')
        content.deleteContent('0 form','form')

        content.openContent('1 upload')
        content.deleteContent('1 upload','form')
   
        content.openContent('2 content')
        content.deleteContent('2 content', 'content')
        
        content.openContent('8 signature')
        content.deleteContent('8 signature', 'document')
    })
}

export function deleteContentsForWiki() {

    it('Deletes created contents', () => {
        cy.visit('/content')

        content.openContent('2 content')
        content.deleteContent('2 content', 'content')
        content.openContent('3 quiz')
        content.deleteContent('3 quiz', 'content')
        content.openContent('4 form')
        content.deleteContent('4 form', 'content')
        content.openContent('5 files')
        content.deleteContent('5 files', 'content')
        content.openContent('6 video')
        content.deleteContent('6 video', 'content')
        content.openContent('7 notion')
        content.deleteContent('7 notion', 'content')
    })
}

export function createForm() {

    it('Creates custom form', () => {
        cy.visit('/content')

        content.createContent('Custom form', 'form')
        content.openContent('Custom form')
        content.createSegment('Custom form', 'Form')
        content.createCustomForm('Custom form')
    })
}

export function deleteForm() {

    it('Deletes custom form', () => {
        cy.visit('/content')

        content.openContent('Custom form')
        content.deleteContent('Custom form','form')
    })
}

// template
export function createTemplate() {

    it('Creates a template, adds section and adds contents', () => {
        cy.visit('/templates')

        template.createTemplate('Premium', 'consists of all contents')

        template.openTemplate('Premium')
        template.openModule('PREBOARDING')

        template.addPhase('form')
        template.addTask('0 form', 'description', true, content[0])

        template.addPhase('content')
        template.addTask('2 content', 'description', true, content[2])
  
        template.addPhase('docs')
        template.addTask('8 signature', 'description', true, content[8])
    })
}

export function deleteTemplate() {

    it('Deletes created template', () => {
        cy.visit('/templates')

        cy.wait(2000)

        template.openTemplate('Premium')
        template.deleteTemplate('Premium')
    })
}

// files
export function deleteAllFiles() {

    
    it('Deletes all files from workspace', () => {
        cy.visit('/settings/files')

        files.delAllFiles()
    })
}

// custom fields
export function selectCustomFields() {

    it('Selects custom fields', () => {
        cy.visit('/settings/custom-fields')

        keyrole.selectCustomField('Select custom field for employee detail', 'Custom form')
        keyrole.selectCustomField('Select custom field for internal feedback (team member evaulation)', 'Custom form')
        keyrole.selectCustomField('Select custom field for internal feedback (manager evaluation)', 'Custom form')
    })
}

export function deleteCustomFields() {

    it('Deselects custom fields', () => {
        cy.visit('/settings/custom-fields')

        keyrole.deselectCustomField('Select custom field for employee detail')
        keyrole.deselectCustomField('Select custom field for internal feedback (team member evaulation)')
        keyrole.deselectCustomField('Select custom field for internal feedback (manager evaluation)')
    })
}

// inventory
export function createInventory() {

    it('Creates inventory items', () => {
        cy.visit('/inventory')

        inventory.addInventoryItem(item[0])
        inventory.addInventoryItem(item[1])
    })
}

export function deleteInventory() {

    it('Deletes inventory items', () => {
        cy.visit('/inventory')

        inventory.openInventoryDetail(item[0].name)
        inventory.delInventoryItem(item[0].name)

        inventory.openInventoryDetail(item[1].name)
        inventory.delInventoryItem(item[1].name)
    })
}

export function setCharts() {

    it('Sets charts', () => {
        cy.visit('/settings/project-chart')
        cy.get('#mainContent > div.login-spinner').should('not.exist')
        cy.get('.font-semibold:contains("MAIN PROJECT")').should('be.visible')
        cy.wait(1000)
    
        cy.visit('/settings/geo-chart')
        cy.get('#mainContent > div.login-spinner').should('not.exist')
        cy.get('.font-semibold:contains("PRAGUE")').should('be.visible')
        cy.wait(1000)
    })
}

export function createUser() {

    it('Creates user: Creates user', () => {
        cy.visit('/settings/users')
        cy.get('#mainContent > div.login-spinner').should('not.exist')
        setUser.createUser(user[0])
    })

    it('Creates user: Links user with employee', () => {
        cy.visit('/settings/users')
        cy.get('#mainContent > div.login-spinner').should('not.exist')
        setUser.linkAccount(user[0], person[0].surname)
    })
}

export function deleteUser() {

    it('Deletes user', () => {
        cy.visit('/settings/users')
        cy.get('#mainContent > div.login-spinner').should('not.exist')
        setUser.deleteUser(user[0])
    })
}

export function addPosition() {

    it('Adds position to Marek Feuermann', () => {
        cy.visit('/employees')
        cy.get('#mainContent > div.login-spinner').should('not.exist')
        employee.openEmployeeCard('Feuermann')
        position.addToPosition(data.position[3], 'create')
    })
}

export function deletePositionInfo() {

    it('Deletes position: Deletes position on employees card', () => {
        cy.visit('/employees')
        cy.get('#mainContent > div.login-spinner').should('not.exist')
        employee.openEmployeeCard('Feuermann')
        position.deletePosition(data.position[3].name)
    })

    it('Deletes position: Deletes position in org chart', () => {
        cy.visit('settings/organisation-chart')
        cy.get('#mainContent > div.login-spinner').should('not.exist')
        charts.deleteItem(data.position[3].name)
    })
}