import * as positionx from "../employee/position"

/**
 * Adds an employee to the first position in organisation chart
 * 
 * @param {object} person object of a person with all the information
 * @param {object} position object of a position with all needed information
 */
export function addEmployeeToPosition(person, position) {

    cy.get('div:contains("' + position.name + '"):parent + div > :first +').click({force:true})

    // fill info
    cy.get('label:contains("Employee") + div').type(person.surname + '{enter}')
    cy.get('label:contains("SKIP PREBOARDING & ONBOARDING")').click()
    cy.get('label:contains("Contract type") + div').type(position.contract + '{enter}')
    cy.get('label:contains("Type of cooperation") + div').type(position.cooperation + '{enter}')
    cy.get('label:contains("Start date") + div').type(position.start)
    cy.get('label:contains("End date") + div').type(position.end)
    cy.get('label:contains("Team leader") + div').type(person.surname + '{enter}')
    cy.get('label:contains("Position in geo chart") + div').type(position.geo + '{enter}')
    cy.get('[name="fte"]').type(position.fte)
    cy.get('[name="payment"]').type(position.payment)
    cy.get('label:contains("Currency") + div').type(position.currency + '{enter}')

    // save
    cy.get('button:contains("Add employee to position")').click()

    // check
    cy.get('body').should('contain', person.surname)
}

/**
 * Deletes employee from a position in org chart
 * 
 * @param {object} person object of a person with all the information
 */
export function deleteEmployeeFromPosition(person) {

    cy.get('a:contains("'+person.surname+'"):last()').click()

    positionx.deleteLastPosition()
}

/**
 * Adds a new intem to the org/geo/project chart
 * 
 * @param {string} itemName name of the item
 *
 */
export function addItem(itemName) {
    
    cy.get('ol > li:last > div > div > div:last > button').click({force:true})

    cy.get('input').focus().type(itemName, {delay: 500}).should('have.value', itemName).type('{enter}')

    cy.get('ol').should('contain', itemName)
}

/**
 * Renames the item in org/geo/project chart
 * 
 * @param {string} itemName name of the item to be renamed
 * @param {string} newName new name of the item
 */
export function renameItem(itemName, newName) {

    cy.get('div:contains("' + itemName + '"):parent + div > div > button:first').click({force:true})
    cy.get('input').should('have.value', itemName).clear().type(newName, {delay: 500}).then(() => {
        cy.get('input').should('have.value', newName).type('{enter}').then(() => {
            cy.wait(2000)
            cy.get('ol').should('contain', newName)
        })
    })
    
    cy.reload()
    cy.wait(2000)
    cy.get('ol').should('contain', newName)
}

/**
 * Deletes position from org chart
 * 
 * @param {string} itemName name of the position
 */
export function deleteItem(itemName) {

    cy.get('div:contains("' + itemName + '"):parent + div > div > button:last').click({force:true})

    // checks
    cy.wait(500)
    cy.get('ol').should('not.contain', itemName)
}
