/**
 * Selects holiday dates
 *
 * @param {string} date picked day for holiday, in format dd.mm.yyyy
 */
export function selectHolidays(date) {

    cy.get('.block').type(date + '{enter}', {delay: 150})
    cy.get('.pr-2 > .items-stretch > .font-urbanist').click()
    cy.get('.justify-start').should('contain', date)
}

/**
 * Deletes holiday date 
 *
 * @param {string} date picked day to be removed from holidays, in format dd.mm.yyy
 */
export function deselectHolidays(date) {

    cy.get('.justify-start').contains(date).children().click()
}

const days = ['Monday0', 'Tuesday1', 'Wednesday2', 'Thursday3', 'Friday4', 'Saturday5', 'Sunday6']

/**
 * Selects working days
 *
 * @param {[int]} workdays array of days to be selected as working days, Monday to Sunday corresponds to 0-6
 */
export function selectWorkingDays(workdays) {

    workdays.forEach(wday => {
        cy.get('#' + days[wday]).click({ force: true })
    })

    workdays.forEach(wday => {
        cy.get('#' + days[wday]).should('have.attr', 'checked')
    })
}

/**
 * Deselects working days 
 *
 * @param {[int]} workdays array of days to be deselected as working days, Monday to Sunday corresponds to 0-6
 */
export function deselectWorkingDays(workdays) {

    workdays.forEach(wday => {
        cy.get('#' + days[wday]).click({ force: true })
    })


    workdays.forEach(wday => {
        cy.get('#' + days[wday]).should('not.have.attr', 'checked')
    })
}

/**
 * Deselects all chosen working days
 */
export function deselectWorkingDaysAll() {

    cy.get('#Tuesday1').click({ force: true })
    cy.get('#Saturday5').click({ force: true })
    cy.get('#Sunday6').click({ force: true })

    days.forEach(day => {
        cy.get("#" + day).should('not.have.attr', 'checked')
    })
}

/**
 * Overall function for adding tags to 'Global tag configuration', 
 * 'Languages', 'Type of cooperation', 'Contract types', 'Currencies' and 'Inventories'
 *
 * @param {object} info object of confInfo that holds information about its name, container and delBtn
 * @param {string} item name of the tag to be added
 */
export function addItem(info, item) {

    cy.get(info.container).type(item + '{enter}', {delay: 150})

    cy.get(info.container).parent().parent().should('contain', item)
}

/**
 * Overall function for deleting specific tag from 'Global tag configuration', 
 * 'Languages', 'Type of cooperation', 'Contract types', 'Currencies' and 'Inventories'
 *
 * @param {object} info object of confInfo that holds information about its name, container and delBtn
 * @param {string} item name of the tag to be deleted
 */
export function deleteItem(info, item) {

    cy.get(info.container).parent().parent().should('contain', item)

    cy.get('[aria-label="Remove ' + item + '"]').click()

    cy.get(info.container).parent().parent().should('not.contain', item)
}


/**
 * Overall function for deleting all tags from 'Global tags configuration', 
 * 'Languages', 'Type of cooperation', 'Contract types', 'Currencies' and 'Inventories'
 *
 * @param {object} info object of confInfo that holds information about its name, container and delBtn
 */
export function deleteAllItems(info) {

    cy.get('label:contains("'+info.name+'") + > div > :last > :first').click()
    // cy.wait(500)

    cy.get(info.container).parent().parent().should('have.length', 1)
}

/**
 * Selects 'Language' using select options.
 *
 * @param {string} language names of the option
 */
export function selectLanguage(language) {

    cy.selectOption('Languages', language)
}

export const confInfo = {
    'global tags': {
        name: 'Global tag configuration',
        container: '#react-select-2-input'
    },
    'languages': {
        name: 'Languages',
        container: '#react-select-3-input'
    },
    'default language': {
        name: 'Default language',
        container: '#react-select-4-input'
    },
    'cooperation': {
        name: 'Types of cooperation',
        container: '#react-select-5-input'
    },
    'contract': {
        name: 'Contract types',
        container: '#react-select-6-input'
    },
    'currencies': {
        name: 'Currencies',
        container: '#react-select-7-input'
    },
    'inventories': {
        name: 'Inventory types',
        container: '#react-select-8-input'
    },
    'conditions': {
        name: 'Inventory conditions',
        container: '#react-select-9-input'
    }
}