/**
 * Sends an invitation
 */
 export function sendInv() {

        cy.get('[name="email"]').should('have.attr', 'type', 'text').type('haiyenblana@seznam.cz')
        cy.get('[name="email"]').should('have.value', 'haiyenblana@seznam.cz')

        cy.get('button[type="submit"]:contains("Send invitation")').click()

}

/**
 * Creates user in the system
 * 
 * @param {object} user object containing information about user
 */
export function createUser(user) {

        cy.get('button:contains("Login")').click()
        cy.get('h2:contains("Add new login")').should('exist')

        cy.get('[name="address"]').type(user.email)
        cy.get('label:contains("Password") + div').type(user.password)
        cy.get('label:contains("Repeat password") + div').type(user.password)

        cy.get('button:contains("Create login")').click()

        cy.get('div[id^="headlessui-dialog-panel"]').should('not.exist')
        cy.get('h2:contains("User") + div').should('contain', user.email)
}

/**
 * Deletes user from the system
 * 
 * @param {object} user object containing information about user
 */
export function deleteUser(user) {

        openOptions(user.email, 'Delete login')
        cy.get('button:contains("Confirm")').click()

        cy.get('h2:contains("User logins") + div').should('not.contain', user.email)
}

/**
 * Links user to an existing employee
 * 
 * @param {obejct} user object containing information about user
 * @param {string} surname surname of an employee to be linked to the user
 */
export function linkAccount(user, surname) {

        openOptions(user.email, 'Link account')
        cy.selectOption('Employee', surname)
        cy.get('button:contains("Link account")').click()

        cy.get('td:contains("' + user.email + '") + td').should('contain', surname)
}

/**
 * Unlinks user
 * 
 * @param {obejct} user object containing information about user
 * @param {string} surname surname of an employee to be unlinked from the user
 */
export function unlinkAccount(user, surname) {

        openOptions(user.email, 'Unlink account')

        cy.get('td:contains("' + user.email + '") + td').should('not.contain', surname)
}

/**
 * Changes the role of an account
 * 
 * @param {obejct} user object containing information about user
 * @param {string} role role that the account will be change into - possible options 'ADMINISTRATOR'/'EMPLOYEE'
 */
export function changeRole(user, role='ADMINISTRATOR') {

        if (role === 'ADMINISTRATOR') {

                openOptions('agent007@onboardee.io', 'Grant admin rights' )

                cy.get('h2:contains("User") + div').should('not.contain', user.email)
                cy.get('h2:contains("Admin logins") + div').should('contain', user.email)

        } else if (role === 'EMPLOYEE') {

                openOptions('agent007@onboardee.io', 'Revoke admin rights' )

                cy.get('h2:contains("Admin logins") + div').should('not.contain', user.email)
                cy.get('h2:contains("User logins") + div').should('contain', user.email)
        }
}

/**
 * Help function - Opens options for a given account
 * 
 * @param {string} email accounts email
 * @param {string} optionName name of the button
 */
export function openOptions(email, optionName) {

        cy.get('td:contains("' + email + '") + td + td + td + td + td').click()
        cy.get('div:contains("' + optionName + '"):last').click()
}